Map

Struct Map 

pub struct Map<K, V>(/* private fields */);
The map used to store the properties of a JsonObject.

The backing implementation and hasher are selected by the preserve_order and fast_hash cargo features, but this type exposes the same API regardless of which are enabled. It’s meant to be a drop-in replacement for the standard library’s HashMap.

Implementations

Source

impl<K, V> Map<K, V>

pub fn new() -> Self

Creates an empty map.

pub fn with_capacity(capacity: usize) -> Self

Creates an empty map with at least the specified capacity.

pub fn len(&self) -> usize

Gets the number of entries.

pub fn is_empty(&self) -> bool

Gets if there are no entries.

pub fn capacity(&self) -> usize

Gets the number of entries the map can hold without reallocating.

pub fn clear(&mut self)

Removes all entries.

pub fn iter(&self) -> Iter<'_, K, V>

Iterates over the entries.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

Iterates over the entries with mutable references to the values.

pub fn keys(&self) -> Keys<'_, K, V>

Iterates over the keys.

pub fn values(&self) -> Values<'_, K, V>

Iterates over the values.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

Iterates over mutable references to the values.

pub fn into_keys(self) -> IntoKeys<K, V>

Consumes the map, iterating over its keys.

pub fn into_values(self) -> IntoValues<K, V>

Consumes the map, iterating over its values.

Source

impl<K: Hash + Eq, V> Map<K, V>

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Inserts an entry, returning the previous value for the key if it existed.

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

Gets the entry for the given key for in-place manipulation.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more entries.

pub fn retain<F: FnMut(&K, &mut V) -> bool>(&mut self, f: F)

Retains only the entries for which the predicate returns true.

Source

impl<K: Hash + Eq, V> Map<K, V>

pub fn get<Q>(&self, key: &Q) -> Option<&V>
where Q: Hash + Equivalent<K> + ?Sized,

Gets a reference to the value for the given key.

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where Q: Hash + Equivalent<K> + ?Sized,

Gets a mutable reference to the value for the given key.

pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
where Q: Hash + Equivalent<K> + ?Sized,

Gets the key and value for the given key.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: Hash + Equivalent<K> + ?Sized,

Gets if the map contains the given key.

pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
where Q: Hash + Equivalent<K> + ?Sized,

Removes and returns the value for the given key, preserving the order of the remaining entries.

pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
where Q: Hash + Equivalent<K> + ?Sized,

Removes and returns the entry for the given key, preserving the order of the remaining entries.