pub struct Map<K, V>(/* private fields */);Expand description
The map used to store the properties of a JsonObject.
The backing implementation and hasher are selected by the preserve_order
and fast_hash cargo features, but this type exposes the same API
regardless of which are enabled. It’s meant to be a drop-in replacement for
the standard library’s HashMap.
Implementations
Sourceimpl<K, V> Map<K, V>
impl<K, V> Map<K, V>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty map with at least the specified capacity.
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Gets the number of entries the map can hold without reallocating.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
Iterates over the entries with mutable references to the values.
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
Iterates over mutable references to the values.
Sourcepub fn into_values(self) -> IntoValues<K, V> ⓘ
pub fn into_values(self) -> IntoValues<K, V> ⓘ
Consumes the map, iterating over its values.
Sourceimpl<K: Hash + Eq, V> Map<K, V>
impl<K: Hash + Eq, V> Map<K, V>
Sourcepub fn insert(&mut self, key: K, value: V) -> Option<V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>
Inserts an entry, returning the previous value for the key if it existed.
Sourcepub fn entry(&mut self, key: K) -> Entry<'_, K, V>
pub fn entry(&mut self, key: K) -> Entry<'_, K, V>
Gets the entry for the given key for in-place manipulation.
Sourceimpl<K: Hash + Eq, V> Map<K, V>
impl<K: Hash + Eq, V> Map<K, V>
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
Gets a mutable reference to the value for the given key.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
Gets the key and value for the given key.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Gets if the map contains the given key.
Sourcepub fn remove<Q>(&mut self, key: &Q) -> Option<V>
pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
Removes and returns the value for the given key, preserving the order of the remaining entries.
Sourcepub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
Removes and returns the entry for the given key, preserving the order of the remaining entries.